tinygram library

Classes

BotBase
A base class that holds shared configuration for a Telegram bot.
ChatBase
Base class for all chat types in Tinygram.
TinygramBot
Interface for sending messages and files via Telegram Bot API.
TinygramBotImpl Tinygram
A simple Telegram bot implementation for sending messages and files. It provides methods to send text messages, files, and fetch updates.
TinygramChat
Represents a chat in Tinygram (private chat, group, or channel).

Typedefs

BotToken = String
Represents a Telegram bot token.
ChatID = String
Unique identifier of a chat (private, group or channel).